@@ -14,14 +14,14 @@ from meilisearch_python_async.models import ClientStats, DumpInfo, Health, Index
 class Client:
     """The client to connect to the MeiliSearchApi."""
 
-    def __init__(self, url: str, api_key: str = None, timeout: int = 5) -> None:
+    def __init__(self, url: str, api_key: str = None, timeout: int | None = None) -> None:
         """Class initializer.
 
         Args:
             url: The url to the MeiliSearch API (ex: http://localhost:7700)
             api_key: The optional API key for MeiliSearch. Defaults to None.
             timeout: The amount of time in seconds that the client will wait for a response before
-                timing out. Defaults to 5.
+                timing out. Defaults to None.
         """
         self._http_client = AsyncClient(
             base_url=url, timeout=timeout, headers=self._set_headers(api_key)
